MouseEventKind

Enum MouseEventKind 

#[repr(u32)]
pub enum MouseEventKind {
Show 16 variants HorizontalWheel = 526, LeftButtonDoubleClick = 515, LeftButtonDown = 513, LeftButtonUp = 514, Leave = 675, MiddleButtonDoubleClick = 521, MiddleButtonDown = 519, MiddleButtonUp = 520, Move = 512, RightButtonDoubleClick = 518, RightButtonDown = 516, RightButtonUp = 517, Wheel = 522, XButtonDoubleClick = 525, XButtonDown = 523, XButtonUp = 524,
}
Mouse event type used by SendMouseInput to convey the type of mouse event being sent to WebView. The values of this enum align with the matching WM_* window messages.

Variants



HorizontalWheel = 526

Mouse horizontal wheel scroll event, WM_MOUSEHWHEEL.



LeftButtonDoubleClick = 515

Left button double click mouse event, WM_LBUTTONDBLCLK.



LeftButtonDown = 513

Left button down mouse event, WM_LBUTTONDOWN.



LeftButtonUp = 514

Left button up mouse event, WM_LBUTTONUP.



Leave = 675

Mouse leave event, WM_MOUSELEAVE.



MiddleButtonDoubleClick = 521

Middle button double click mouse event, WM_MBUTTONDBLCLK.



MiddleButtonDown = 519

Middle button down mouse event, WM_MBUTTONDOWN.



MiddleButtonUp = 520

Middle button up mouse event, WM_MBUTTONUP.



Move = 512

Mouse move event, WM_MOUSEMOVE.



RightButtonDoubleClick = 518

Right button double click mouse event, WM_RBUTTONDBLCLK.



RightButtonDown = 516

Right button down mouse event, WM_RBUTTONDOWN.



RightButtonUp = 517

Right button up mouse event, WM_RBUTTONUP.



Wheel = 522

Mouse wheel scroll event, WM_MOUSEWHEEL.



XButtonDoubleClick = 525

First or second X button double click mouse event, WM_XBUTTONDBLCLK.



XButtonDown = 523

First or second X button down mouse event, WM_XBUTTONDOWN.



XButtonUp = 524

First or second X button up mouse event, WM_XBUTTONUP.