pub unsafe extern "stdcall" fn GetAvailableCoreWebView2BrowserVersionString(
browser_executable_folder: PCWSTR,
version_info: *mut LPWSTR,
) -> HRESULTExpand description
Get the browser version info including channel name if it is not the stable channel or the Embedded Edge. Channel names are beta, dev, and canary. If an override exists for the browserExecutableFolder or the channel preference, the override will be used. If there isn’t an override, then the parameter passed to GetAvailableCoreWebView2BrowserVersionString is used.