pub trait ICoreWebView2CompositionControllerInterop: IUnknown {
// Required methods
unsafe fn get_uiaprovider(
&self,
provider: *mut *mut *mut IUnknownVTable,
) -> HRESULT;
unsafe fn get_root_visual_target(
&self,
target: *mut *mut *mut IUnknownVTable,
) -> HRESULT;
unsafe fn put_root_visual_target(
&self,
target: *mut *mut IUnknownVTable,
) -> HRESULT;
}Expand description
This is the ICoreWebView2CompositionControllerInterop interface. Interop interface for the CoreWebView2CompositionController WinRT object to allow WinRT end developers to be able to use the COM interfaces as parameters for some methods.
Required Methods
Sourceunsafe fn get_uiaprovider(
&self,
provider: *mut *mut *mut IUnknownVTable,
) -> HRESULT
unsafe fn get_uiaprovider( &self, provider: *mut *mut *mut IUnknownVTable, ) -> HRESULT
Returns the UI Automation Provider for the WebView.
Sourceunsafe fn get_root_visual_target(
&self,
target: *mut *mut *mut IUnknownVTable,
) -> HRESULT
unsafe fn get_root_visual_target( &self, target: *mut *mut *mut IUnknownVTable, ) -> HRESULT
The RootVisualTarget is a visual in the hosting app’s visual tree. This visual is where the WebView will connect its visual tree. The app uses this visual to position the WebView within the app. The app still needs to use the Bounds property to size the WebView. The RootVisualTarget property can be an IDCompositionVisual or a Windows::UI::Composition::ContainerVisual. WebView will connect its visual tree to the provided visual before returning from the property setter. The app needs to commit on its device setting the RootVisualTarget property. The RootVisualTarget property supports being set to nullptr to disconnect the WebView from the app’s visual tree. \snippet ViewComponent.cpp SetRootVisualTarget \snippet ViewComponent.cpp BuildDCompTree
Sourceunsafe fn put_root_visual_target(
&self,
target: *mut *mut IUnknownVTable,
) -> HRESULT
unsafe fn put_root_visual_target( &self, target: *mut *mut IUnknownVTable, ) -> HRESULT
Set the RootVisualTarget property.