Trait webview2_sys::ICoreWebView2FrameInfo[][src]

pub trait ICoreWebView2FrameInfo: IUnknown {
    unsafe fn get_name(&self, name: *mut LPWSTR) -> HRESULT;
unsafe fn get_source(&self, source: *mut LPWSTR) -> HRESULT; }

Provides a set of properties for a frame in the ICoreWebView2.

Required methods

unsafe fn get_name(&self, name: *mut LPWSTR) -> HRESULT[src]

The name attribute of the frame, as in <iframe name="frame-name" ...>. The returned string is empty when the frame has no name attribute.

unsafe fn get_source(&self, source: *mut LPWSTR) -> HRESULT[src]

The URI of the document in the frame.

Loading content...