pub trait ICoreWebView2PermissionRequestedEventArgs: IUnknown {
// Required methods
unsafe fn get_uri(&self, uri: *mut LPWSTR) -> HRESULT;
unsafe fn get_permission_kind(
&self,
permission_kind: *mut PermissionKind,
) -> HRESULT;
unsafe fn get_is_user_initiated(
&self,
is_user_initiated: *mut BOOL,
) -> HRESULT;
unsafe fn get_state(&self, state: *mut PermissionState) -> HRESULT;
unsafe fn put_state(&self, state: PermissionState) -> HRESULT;
unsafe fn get_deferral(
&self,
deferral: *mut *mut *mut ICoreWebView2DeferralVTable,
) -> HRESULT;
}Expand description
Event args for the PermissionRequested event.
Required Methods
Sourceunsafe fn get_uri(&self, uri: *mut LPWSTR) -> HRESULT
unsafe fn get_uri(&self, uri: *mut LPWSTR) -> HRESULT
The origin of the web content that requests the permission.
Sourceunsafe fn get_permission_kind(
&self,
permission_kind: *mut PermissionKind,
) -> HRESULT
unsafe fn get_permission_kind( &self, permission_kind: *mut PermissionKind, ) -> HRESULT
The type of the permission that is requested.
Sourceunsafe fn get_is_user_initiated(&self, is_user_initiated: *mut BOOL) -> HRESULT
unsafe fn get_is_user_initiated(&self, is_user_initiated: *mut BOOL) -> HRESULT
TRUE when the permission request was initiated through a user gesture.
> [!NOTE]\n> Being initiated through a user gesture does not mean that user intended to access the associated resource.
Sourceunsafe fn get_state(&self, state: *mut PermissionState) -> HRESULT
unsafe fn get_state(&self, state: *mut PermissionState) -> HRESULT
The status of a permission request, (for example is the request is granted).
The default value is COREWEBVIEW2_PERMISSION_STATE_DEFAULT.
Sourceunsafe fn put_state(&self, state: PermissionState) -> HRESULT
unsafe fn put_state(&self, state: PermissionState) -> HRESULT
Sets the State property.
Sourceunsafe fn get_deferral(
&self,
deferral: *mut *mut *mut ICoreWebView2DeferralVTable,
) -> HRESULT
unsafe fn get_deferral( &self, deferral: *mut *mut *mut ICoreWebView2DeferralVTable, ) -> HRESULT
Gets an ICoreWebView2Deferral object. Use the deferral object to make
the permission decision at a later time.