Trait webview2_sys::ICoreWebView2_2[][src]

pub trait ICoreWebView2_2: ICoreWebView2 {
    unsafe fn add_web_resource_response_received(
        &self,
        event_handler: *mut *mut ICoreWebView2WebResourceResponseReceivedEventHandlerVTable,
        token: *mut EventRegistrationToken
    ) -> HRESULT;
unsafe fn remove_web_resource_response_received(
        &self,
        token: EventRegistrationToken
    ) -> HRESULT;
unsafe fn navigate_with_web_resource_request(
        &self,
        request: *mut *mut ICoreWebView2WebResourceRequestVTable
    ) -> HRESULT;
unsafe fn add_domcontent_loaded(
        &self,
        event_handler: *mut *mut ICoreWebView2DOMContentLoadedEventHandlerVTable,
        token: *mut EventRegistrationToken
    ) -> HRESULT;
unsafe fn remove_domcontent_loaded(
        &self,
        token: EventRegistrationToken
    ) -> HRESULT;
unsafe fn get_cookie_manager(
        &self,
        cookie_manager: *mut *mut *mut ICoreWebView2CookieManagerVTable
    ) -> HRESULT;
unsafe fn get_environment(
        &self,
        environment: *mut *mut *mut ICoreWebView2EnvironmentVTable
    ) -> HRESULT; }

A continuation of ICoreWebView2 interface.

Required methods

unsafe fn add_web_resource_response_received(
    &self,
    event_handler: *mut *mut ICoreWebView2WebResourceResponseReceivedEventHandlerVTable,
    token: *mut EventRegistrationToken
) -> HRESULT
[src]

Add an event handler for the WebResourceResponseReceived event. WebResourceResponseReceived is raised when the WebView receives the response for a request for a web resource (any URI resolution performed by the WebView; such as HTTP/HTTPS, file and data requests from redirects, navigations, declarations in HTML, implicit favicon lookups, and fetch API usage in the document). The host app can use this event to view the actual request and response for a web resource. There is no guarantee about the order in which the WebView processes the response and the host app’s handler runs. The app’s handler will not block the WebView from processing the response. \snippet ScenarioAuthentication.cpp WebResourceResponseReceived

unsafe fn remove_web_resource_response_received(
    &self,
    token: EventRegistrationToken
) -> HRESULT
[src]

Remove an event handler previously added with add_WebResourceResponseReceived.

unsafe fn navigate_with_web_resource_request(
    &self,
    request: *mut *mut ICoreWebView2WebResourceRequestVTable
) -> HRESULT
[src]

Navigates using a constructed WebResourceRequest object. This lets you provide post data or additional request headers during navigation. The headers in the WebResourceRequest override headers added by WebView2 runtime except for Cookie headers. Method can only be either “GET” or “POST”. Provided post data will only be sent only if the method is “POST” and the uri scheme is HTTP(S). \snippet ScenarioNavigateWithWebResourceRequest.cpp NavigateWithWebResourceRequest

unsafe fn add_domcontent_loaded(
    &self,
    event_handler: *mut *mut ICoreWebView2DOMContentLoadedEventHandlerVTable,
    token: *mut EventRegistrationToken
) -> HRESULT
[src]

Add an event handler for the DOMContentLoaded event. DOMContentLoaded is raised when the initial html document has been parsed. This aligns with the the document’s DOMContentLoaded event in html.

\snippet ScenarioDOMContentLoaded.cpp DOMContentLoaded

unsafe fn remove_domcontent_loaded(
    &self,
    token: EventRegistrationToken
) -> HRESULT
[src]

Remove an event handler previously added with add_DOMContentLoaded.

Gets the cookie manager object associated with this ICoreWebView2. See ICoreWebView2CookieManager.

\snippet ScenarioCookieManagement.cpp CookieManager

unsafe fn get_environment(
    &self,
    environment: *mut *mut *mut ICoreWebView2EnvironmentVTable
) -> HRESULT
[src]

Exposes the CoreWebView2Environment used to create this CoreWebView2.

Loading content...