Trait webview2_sys::ICoreWebView2AcceleratorKeyPressedEventArgs [−][src]
pub trait ICoreWebView2AcceleratorKeyPressedEventArgs: IUnknown { unsafe fn get_key_event_kind(
&self,
key_event_kind: *mut KeyEventKind
) -> HRESULT; unsafe fn get_virtual_key(&self, virtual_key: *mut u32) -> HRESULT; unsafe fn get_key_event_lparam(&self, l_param: *mut i32) -> HRESULT; unsafe fn get_physical_key_status(
&self,
physical_key_status: *mut PhysicalKeyStatus
) -> HRESULT; unsafe fn get_handled(&self, handled: *mut BOOL) -> HRESULT; unsafe fn put_handled(&self, handled: BOOL) -> HRESULT; }
Event args for the AcceleratorKeyPressed event.
Required methods
unsafe fn get_key_event_kind(
&self,
key_event_kind: *mut KeyEventKind
) -> HRESULT[src]
&self,
key_event_kind: *mut KeyEventKind
) -> HRESULT
The key event type that caused the event to run.
unsafe fn get_virtual_key(&self, virtual_key: *mut u32) -> HRESULT[src]
The Win32 virtual key code of the key that was pressed or released. It
is one of the Win32 virtual key constants such as VK_RETURN or an
(uppercase) ASCII value such as A. Verify whether Ctrl or Alt
are pressed by running GetKeyState(VK_CONTROL) or
GetKeyState(VK_MENU).
unsafe fn get_key_event_lparam(&self, l_param: *mut i32) -> HRESULT[src]
The LPARAM value that accompanied the window message. For more
information, navigate to
[WM_KEYDOWN][WindowsWin32InputdevWmKeydown]
and
[WM_KEYUP][WindowsWin32InputdevWmKeyup].
[WindowsWin32InputdevWmKeydown]: /windows/win32/inputdev/wm-keydown “WM_KEYDOWN message | Microsoft Docs”
[WindowsWin32InputdevWmKeyup]: /windows/win32/inputdev/wm-keyup “WM_KEYUP message | Microsoft Docs”
unsafe fn get_physical_key_status(
&self,
physical_key_status: *mut PhysicalKeyStatus
) -> HRESULT[src]
&self,
physical_key_status: *mut PhysicalKeyStatus
) -> HRESULT
A structure representing the information passed in the LPARAM of the
window message.
unsafe fn get_handled(&self, handled: *mut BOOL) -> HRESULT[src]
During AcceleratorKeyPressedEvent handler invocation the WebView is
blocked waiting for the decision of if the accelerator is handled by the
host (or not). If the Handled property is set to TRUE then this
prevents the WebView from performing the default action for this
accelerator key. Otherwise the WebView performs the default action for
the accelerator key.
unsafe fn put_handled(&self, handled: BOOL) -> HRESULT[src]
Sets the Handled property.